==> anyblok_postgres-0.1.0.tar.gz: anyblok_postgres-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
# This file is a part of the AnyBlok / Postgres project
#
#    Copyright (C) 2017 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
#
# This Source Code Form is subject to the terms of the Mozilla Public License,
# v. 2.0. If a copy of the MPL was not distributed with this file,You can
# obtain one at http://mozilla.org/MPL/2.0/.
from setuptools import setup, find_packages
import os

version = '0.1.0'

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), 'r',
          encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(
    os.path.join(here, 'doc', 'CHANGES.rst'), 'r', encoding='utf-8'
) as change:
    CHANGES = change.read()

requirements = [
    'anyblok',
    'psycopg2',
]

setup(
    name='anyblok_postgres',
    version=version,
    description="Versionned attachment for AnyBlok",
    long_description=readme + '\n' + CHANGES,
    author="jssuzanne",
    author_email='jssuzanne@anybox.fr',
    url="http://docs.anyblok-postgres.anyblok.org/%s" % version,
    packages=find_packages(),
    entry_points={
    },
    include_package_data=True,
    install_requires=requirements,
    zip_safe=False,
    keywords='anyblok postgres',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    test_suite='tests',
    tests_require=requirements + ['nose'],
)

==> anyblok_postgres-1.0.0.tar.gz: anyblok_postgres-1.0.0/setup.py <==
# -*- coding: utf-8 -*-
# This file is a part of the AnyBlok / Postgres project
#
#    Copyright (C) 2017 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
#    Copyright (C) 2021 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
#
# This Source Code Form is subject to the terms of the Mozilla Public License,
# v. 2.0. If a copy of the MPL was not distributed with this file,You can
# obtain one at http://mozilla.org/MPL/2.0/.
from setuptools import setup, find_packages
import os

from anyblok_postgres.release import version

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), 'r',
          encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(
    os.path.join(here, 'doc', 'CHANGES.rst'), 'r', encoding='utf-8'
) as change:
    CHANGES = change.read()

requirements = [
    'anyblok >= 1.1.0',
]

setup(
    name='anyblok_postgres',
    version=version,
    description="Versionned attachment for AnyBlok",
    long_description=readme + '\n' + CHANGES,
    author="jssuzanne",
    author_email='jssuzanne@anybox.fr',
    url="http://docs.anyblok-postgres.anyblok.org/%s" % version,
    packages=find_packages(),
    entry_points={
    },
    include_package_data=True,
    install_requires=requirements,
    zip_safe=False,
    keywords='anyblok postgres',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    test_suite='tests',
    tests_require=requirements + ['pytest'],
)
